@@ -13,9 +13,13 @@ def extract_argscode():
     # open file to output source code
     source_file = open("parse_args.py", "w")
     # extract source code of parse_args
-    parse_args_source = inspect.getsource(BaseConfig.parse_args)
-    # remove first line
+    parse_args_source = inspect.getsource(BaseConfig.get_arg_parser)
+    # remove first three lines
     parse_args_source = parse_args_source[parse_args_source.index('\n')+1:]
+    parse_args_source = parse_args_source[parse_args_source.index('\n')+1:]
+    parse_args_source = parse_args_source[parse_args_source.index('\n')+1:]
+    # insert at beginning
+    parse_args_source = f'parser = argparse.ArgumentParser(prog="lbsntransform")\n{parse_args_source}'
     # unindent all other lines
     parse_args_source = parse_args_source.lstrip().replace('\n        ', '\n')
     # replace version string
@@ -28,10 +32,12 @@ def extract_argscode():
     source_file.write('import argparse\n')
     source_file.write('import argdown\n')
     source_file.write('from pathlib import Path\n')
-    source_file.write('from lbsntransform import BaseConfig\n')
     # fix argparse name
     parse_args_source = parse_args_source.replace(
         'ArgumentParser()', 'ArgumentParser(prog="lbsntransform")')
+    # replace method leftover
+    parse_args_source = parse_args_source.replace(
+        'return parser', 'args = parser.parse_args()')
     # replace two empty spaces on str line ends with non-breaking spaces,
     # protecting line breaks during python-markdown conversion
     parse_args_source = parse_args_source.replace(
