@@ -11,6 +11,7 @@ from lbsntransform.tools.helper_functions import HelperFunctions as HF
 
 FACET = 'temporal'
 
+
 class TimestampBase(hll.HllBase):
     """Extends Base Class"""
     NAME = hll.HllBaseRef(facet=FACET, base='timestamp')
@@ -183,6 +184,7 @@ class MonthofyearBase(hll.HllBase):
         if post_date_time:
             self.key['monthofyear'] = post_date_time.month
 
+
 class MonthHashtagBase(hll.HllBase):
     """Composite Base (c-base) that extends from HLL base Class
 
@@ -215,6 +217,7 @@ class MonthHashtagBase(hll.HllBase):
                 "Parsing of MonthHashtagBase only supported "
                 "from lbsn.Post")
 
+
 class MonthLatLngBase(hll.HllBase):
     """Composite Base (c-base) that extends from HLL base Class
 
@@ -255,4 +258,52 @@ class MonthLatLngBase(hll.HllBase):
         else:
             raise ValueError(
                 "Parsing of MonthLatLngBase only supported "
-                "from lbsn.Post")
\ No newline at end of file
+                "from lbsn.Post")
+
+
+class MonthHashtagLatLngBase(hll.HllBase):
+    """Composite Base (c-base) that extends from hll.HllBase Class
+
+    Note: To distinguish c-bases which are composite bases combining
+    aspects from multiple facets, they're termed with a leading underscore
+    """
+    NAME = hll.HllBaseRef(facet=FACET, base='_month_hashtag_latlng')
+
+    def __init__(self, record: lbsn.Post = None, hashtag: str = None):
+
+        super().__init__()
+        self.key['year'] = None
+        self.key['month'] = None
+        self.key['hashtag'] = None
+        self.key['latitude'] = None
+        self.key['longitude'] = None
+        self.attrs['latlng_geom'] = None
+        if hashtag is None:
+            # init empty
+            return
+        self.key['hashtag'] = hashtag.lower()
+
+        if record is None:
+            # init empty
+            return
+
+        if not isinstance(record, lbsn.Post):
+            raise ValueError(
+                "Parsing of MonthHashtagLatLngBase only supported "
+                "from lbsn.Post")
+        post_date_time = HLF.merge_dates_post(
+            record)
+        if post_date_time:
+            date = post_date_time.date()
+            self.key['year'] = date.year
+            self.key['month'] = date.month
+        coordinates_geom = record.post_latlng
+        coordinates = HF.get_coordinates_from_ewkt(
+            coordinates_geom
+        )
+        self.key['latitude'] = coordinates.lat
+        self.key['longitude'] = coordinates.lng
+        # additional (optional) attributes
+        # formatted ready for sql upsert
+        self.attrs['latlng_geom'] = HF.return_ewkb_from_geotext(
+            coordinates_geom)
