@@ -115,6 +115,7 @@ def merge_base_metrics(base1, base2):
             continue
         base1.metrics[key] |= new_set
 
+
 def append_baserecord(
         base_records: List['HllBase'], base_record: 'HllBase'):
     """Append base_record to list, if all keys have valid values (not None)"""
@@ -124,6 +125,7 @@ def append_baserecord(
         return
     base_records.append(base_record)
 
+
 def base_factory(facet=None, base=None, record: lbsn.Post = None):
     """Base is initialized based on facet-base tuple
     and constructed by parsing lbsn records
@@ -147,7 +149,7 @@ def base_factory(facet=None, base=None, record: lbsn.Post = None):
                 base_structure(tag))
     elif base == 'emoji':
         # do nothing
-        all_post_emoji = HF.get_all_post_emoji(record.post_body)
+        all_post_emoji = HF.extract_emoji(record.post_body)
         for emoji in all_post_emoji:
             # create base for each term
             records.append(
@@ -183,7 +185,7 @@ def base_factory(facet=None, base=None, record: lbsn.Post = None):
     elif base == '_emoji_latlng':
         # any term mentioned in title,
         # body or hashtag
-        all_post_emoji = HF.get_all_post_emoji(record.post_body)
+        all_post_emoji = HF.extract_emoji(record.post_body)
         for emoji in all_post_emoji:
             # create base for each emoji
             base_record = base_structure(record=record, emoji=emoji)
@@ -194,6 +196,12 @@ def base_factory(facet=None, base=None, record: lbsn.Post = None):
         for tag in tag_terms:
             base_record = base_structure(record=record, hashtag=tag)
             append_baserecord(records, base_record)
+    elif base == '_month_hashtag_latlng':
+        # any hashtag explicitly used
+        tag_terms = HF.filter_terms(record.hashtags)
+        for tag in tag_terms:
+            base_record = base_structure(record=record, hashtag=tag)
+            append_baserecord(records, base_record)
     else:
         # init for all other bases with single lbsn record
         base_record = base_structure(record)
