@@ -17,9 +17,9 @@ import string
 from datetime import timezone
 from json import JSONDecodeError, JSONDecoder
 from pathlib import Path
-from typing import List, Optional, Set, Union
+from typing import List, Optional, Set, Union, Dict
+from emoji import distinct_emoji_list
 
-import emoji
 import regex
 from google.protobuf.timestamp_pb2 import Timestamp
 from lbsnstructure import lbsnstructure_pb2 as lbsn
@@ -39,24 +39,27 @@ else:
     from google.protobuf.internal.containers import \
         ScalarMap  # pylint: disable=no-name-in-module
 
-NLTK_AVAIL = True
+NLTK_AVAIL = None
+STOPWORDS = None
 try:
     # check if nltk is installed
     import nltk
+    NLTK_AVAIL = True
 except ImportError:
-    NLTK_AVAIL = False
+    pass
 
 if NLTK_AVAIL:
     try:
         # check if stopwords corpus is available
         from nltk.corpus import stopwords
+        STOPWORDS = stopwords.words('english')
     except LookupError:
         print(
             'Please use '
             '`python -c \'import nltk;nltk.download("stopwords")\'` '
             'to install stopwords resource globally. Continuing without '
             'nltk stopwords filter..')
-        NLTK_AVAIL = False
+        STOPWORDS = None
 # pylint: disable=no-member
 
 
@@ -133,12 +136,6 @@ class HelperFunctions():
             body_terms, title_terms, tag_terms)
         return all_post_terms
 
-    @staticmethod
-    def get_all_post_emoji(
-            post_body: str) -> Set[str]:
-        """Returns all post emoji combined in single set"""
-        return set(HelperFunctions.extract_emoji(post_body))
-
     @staticmethod
     def select_terms(
             text_s: str, selection_list: List[str] = None) -> Set[str]:
@@ -182,10 +179,10 @@ class HelperFunctions():
         return resultwords
 
     @staticmethod
-    def nltk_stopword_filter(term: str) -> bool:
+    def nltk_stopword_filter(term: str, nltk_avail=NLTK_AVAIL, stopwords=STOPWORDS) -> bool:
         """Filter term against nltk stopwords (english)"""
-        if NLTK_AVAIL:
-            if term in stopwords.words('english'):
+        if nltk_avail is not None and stopwords is not None:
+            if term in stopwords:
                 return False
         return True
 
@@ -232,7 +229,7 @@ class HelperFunctions():
 
     @staticmethod
     def extract_hashtags_from_string(
-        text_str: str) -> Set[str]:
+            text_str: str) -> Set[str]:
         """Extract hashtags with leading hash-character (#) from string
 
         - removes # from hashtags
@@ -247,7 +244,7 @@ class HelperFunctions():
 
     @staticmethod
     def extract_atmentions_from_string(
-        text_str: str) -> Set[str]:
+            text_str: str) -> Set[str]:
         """Extract @-mentions with leading hash-character (@) from string
 
         - removes @ from mentions
@@ -394,46 +391,10 @@ class HelperFunctions():
         return cleantext
 
     @staticmethod
-    def extract_emoji_fast(str_text: str):
-        """Extract list of emoji from string
-
-        Note:
-            cannot detect grapheme clusters or flags"""
-        # str = str.decode('utf-32').encode('utf-32', 'surrogatepass')
-        # return list(c for c in str if c in emoji.UNICODE_EMOJI)
-        return set(c for c in str_text if c in emoji.UNICODE_EMOJI)
-
-    @staticmethod
-    def extract_emoji(string_with_emoji: str) -> Set[str]:
-        """Extract emoji and flags using regex package
-
-        This is a new version to extract emoji (see old method:
-        _extract_emoji_old). Code source:
-        https://stackoverflow.com/a/49242754/4556479
-        This method supports extracting grapheme clusters,
-        emoji constructed of multiple emoji (the "perceived
-        pictograms")
-
-        Compare:
-        A: _extract_emoji_old:
-        Total emoji count for the 100 most
-        used emoji in selected area: 27722.
-        Total distinct emoji (DEC): 918
-        B: _extract_emoji:
-        Total emoji count for the 100 most
-        used emoji in selected area: 25793.
-        Total distinct emoji (DEC): 1349
-
-        Original Code @ sheldonzy:
-        https://stackoverflow.com/a/49242754/4556479
-        """
-        emoji_set = set()
-        # use \X (eXtended grapheme cluster) regular expression:
-        data = regex.findall(r'\X', string_with_emoji)
-        for grapheme in data:
-            if any(char in emoji.UNICODE_EMOJI["en"] for char in grapheme):
-                emoji_set.add(grapheme)
-        return emoji_set
+    def extract_emoji(
+            string_with_emoji: str) -> Set[str]:
+        """Extract distinct set of emoji from string"""
+        return distinct_emoji_list(string_with_emoji)
 
     @staticmethod
     def get_rectangle_bounds(points):
@@ -827,5 +788,5 @@ class HelperFunctions():
         if skipped_geo is None and skipped_ignore is None:
             return ''
         else:
-            report_str = ' '.join([skipped_geo, skipped_ignore])
+            report_str = ' '.join(filter(None, [skipped_geo, skipped_ignore]))
             return report_str
